<p align="center">

<a href="https://github.com/generate/generate">
<img height="150" width="150" src="https://raw.githubusercontent.com/generate/generate/master/docs/logo.png">
</a>
</p>

Generate a license file. Choose any of the licenses supported by https://github.com/github/choosealicense.com.

# generate-license

[![NPM version](https://img.shields.io/npm/v/generate-license.svg?style=flat)](https://www.npmjs.com/package/generate-license) [![NPM monthly downloads](https://img.shields.io/npm/dm/generate-license.svg?style=flat)](https://npmjs.org/package/generate-license) [![Build Status](https://img.shields.io/travis/generate/generate-license.svg?style=flat)](https://travis-ci.org/generate/generate-license)

![generate-license demo](https://raw.githubusercontent.com/generate/generate-license/master/docs/demo.gif)

- [Install](#install)
- [Generate a license](#generate-a-license)
- [API](#api)
- [Getting started](#getting-started)
  * [Install](#install-1)
  * [CLI](#cli)
  * [Help](#help)
- [Tasks](#tasks)
- [Next Steps](#next-steps)
- [About](#about)
  * [What is "Generate"?](#what-is-generate)
  * [Related projects](#related-projects)
  * [Community](#community)
  * [Contributors](#contributors)
  * [Contributing](#contributing)
  * [Running tests](#running-tests)
  * [Release history](#release-history)
  * [Author](#author)
  * [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

## Install

To run this generator from the command line you must install both [generate](https://github.com/generate/generate) and `generate-license`:

```sh
# install generate and generate-license
$ npm install --global generate generate-license
# install only generate-license
$ npm install --global generate-license
```

## Generate a license

Use [generate's CLI](https://github.com/generate/generate) to write a license file to the current working directory:

```sh
# prompts you to choose a license to generate
$ gen license
```

The file is automatically named according to preferences defined at GitHub's [choosealicense.com](https://github.com/github/choosealicense.com) repository (usually it's `LICENSE`, but not always. See the license files in that repository for more details).

**Specify the license to generate**

If you don't want to be prompted, you can specify the license up front:

```sh
$ gen license:<license name>
# example
$ gen license:mit
```

**Specify output directory**

```sh
# write a license file to "some-folder/LICENSE"
$ gen license -d some-folder
```

## API

Visit [generate's documenatation](https://github.com/generate/generate) to learn how to use this generator as a plugin or sub-generator.

## Getting started

### Install

**Installing the CLI**

To run the `readme` generator from the command line, you'll need to install [Generate](https://github.com/generate/generate) globally first. You can do that now with the following command:

```sh
$ npm install --global generate
```

This adds the `gen` command to your system path, allowing it to be run from any directory.

**Install generate-license**

Install this module with the following command:

```sh
$ npm install --global generate-license
```

### CLI

Run this generator's `default` [task](https://github.com/generate/generate/blob/master/docs/tasks.md#default) with the following command:

```sh
$ gen readme
```

**What you should see in the terminal**

If completed successfully, you should see both `starting` and `finished` events in the terminal, like the following:

```sh
[00:44:21] starting ...
...
[00:44:22] finished ✔
```

If you do not see one or both of those events, please [let us know about it](../../issues).

### Help

To see a general help menu and available commands for Generate's CLI, run:

```sh
$ gen help
```

## Available tasks

All available tasks for this generator.

### [default](generator.js#L34)

The `default` task prompts you to choose the `LICENSE` to generate. All licenses from [github/choosealicense.com](https://github.com/github/choosealicense.com) are available.

**Example**

```sh
$ gen license
$ gen license --dest ./docs
# or
$ gen license:choose
$ gen license:choose --dest ./docs
```

Visit Generate's [documentation for tasks](https://github.com/generate/generate/blob/master/docs/tasks.md).

## Next steps

### Running unit tests

It's never too early to begin running unit tests. When you're ready to get started, the following command will ensure the project's dependencies are installed then run all of the unit tests:

```sh
$ npm install && test
```

### Publishing your generator

If you're tests are passing and you're ready to publish your generator to [npm](https://www.npmjs.com), you can do that now with the following command:

**Are you sure you're ready?!**

Let's go!

```sh
$ npm publish
```

## About

### What is "Generate"?

Generate is a command line tool and developer framework for scaffolding out new GitHub projects using [generators](https://github.com/generate/generate/blob/master/docs/generators.md) and [tasks](https://github.com/generate/generate/blob/master/docs/tasks.md).

Answers to prompts and the user's environment can be used to determine the templates, directories, files and contents to build. Support for [gulp](http://gulpjs.com), [base](https://github.com/node-base/base) and [assemble](https://github.com/assemble/assemble) plugins, and much more.

**For more information**:

* Visit the [generate project](https://github.com/generate/generate/)
* Visit the [generate documentation](https://github.com/generate/generate/blob/master/docs/)
* Find [generators on npm](https://www.npmjs.com/browse/keyword/generate-generator) (help us [author generators](https://github.com/generate/generate/blob/master/docs/micro-generators.md))

### Related projects

* [generate-eslint](https://www.npmjs.com/package/generate-eslint): Generate a new `.eslintrc.json` or `.eslintignore` file from a pre-defined or user-defined template. Can be… [more](https://github.com/generate/generate-eslint) | [homepage](https://github.com/generate/generate-eslint "Generate a new `.eslintrc.json` or `.eslintignore` file from a pre-defined or user-defined template. Can be used from the command line when installed globally, or as a plugin in your own generator.")
* [generate-install](https://www.npmjs.com/package/generate-install): Generator that automatically detects the dependencies or devDependencies to install based on the templates or… [more](https://github.com/generate/generate-install) | [homepage](https://github.com/generate/generate-install "Generator that automatically detects the dependencies or devDependencies to install based on the templates or includes that are dynamically used by your generator. This can be used as a sub-generator or plugin in your own generator.")
* [generate-package](https://www.npmjs.com/package/generate-package): Generate a package.json from a pre-defined or user-defined template. This generator can be used from… [more](https://github.com/generate/generate-package) | [homepage](https://github.com/generate/generate-package "Generate a package.json from a pre-defined or user-defined template. This generator can be used from the command line when globally installed, or as a plugin or sub-generator in your own generator.")

### Community

Bigger community means more plugins, better support and more progress. Help us make Generate better by spreading the word:

* Show your love by starring the project
* Tweet about Generate. Mention using `@generatejs`, or use the `#generatejs` hashtag
* Get implementation help on [StackOverflow](http://stackoverflow.com/questions/tagged/generate) with the `generatejs` tag
* Discuss Generate with us on [Gitter](https://gitter.im/generate/generate)
* If you publish a generator, to make your project as discoverable as possible, please add the unique keyword `generategenerator` to your project's package.json.

### Contributors

| **Commits** | **Contributor** | 
| --- | --- |
| 78 | [jonschlinkert](https://github.com/jonschlinkert) |
| 10 | [pointnet](https://github.com/pointnet) |
| 4 | [doowb](https://github.com/doowb) |

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Running tests

Running and reviewing unit tests is a great way to get familiarized with a library and its API. You can install dependencies and run tests with the following command:

```sh
$ npm install && npm test
```

### Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](https://twitter.com/jonschlinkert)

### License

Copyright © 2017, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT License](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.6.0, on October 17, 2017._